@@ -1,6 +1,8 @@
 from .logger import Fake_Logger
 import os
 from collections import OrderedDict
+import tempfile
+import shutil
 
 class Plugin_Base:
     '''
@@ -16,6 +18,7 @@ class Plugin_Base:
                     (new multiprocess or threads)
                     on_new_process_init (only multiprocess)
                     on_parse_files / on_parse_pages / on_parse_blog
+                    on_js_vars
                     on_add_navbar_items
                     on_render_vars
                     on_new_process_del (only multiprocess)
@@ -52,10 +55,11 @@ class Plugin_Base:
         '''
         pass
 
-    def on_parse_start(self, type_name, doc_config, new_config):
+    def on_parse_start(self, type_name, url, dirs, doc_config, new_config):
         '''
             call when start parse one doc
             @type_name canbe "doc" "page" "blog"
+            #url doc url, e.g. /get_started/zh/
             @doc_config config of doc, get from config.json or config.yaml
             @new_config this plugin's config from doc_config
         '''
@@ -142,8 +146,11 @@ class Plugin_Base:
     
     def on_add_html_footer_js_items(self, type_name):
         '''
-            add js(/or other tags) items to end of body, should be a html tag, e.g.
-                <script src="..."></script>
+            add js(/or other tags) items to end of body, should be absolute file path or a html tag or a dict object, e.g.
+                ['<script src="..."></script>', '/home/abc/test.js', {
+                    "path": "/home/abc/test.js",
+                    "options": ["async"]
+                }]
             @type_name canbe "doc" "page" "blog"
         '''
         return []
@@ -251,6 +258,13 @@ class Plugin_Base:
         '''
         return []
 
+    def on_js_vars(self):
+        '''
+            return the vars you wish store in head tag of html,
+            to use these vars in your js, e.g. `var conf=js_vars["teedoc-plugin-ad-hint"];`
+        '''
+        return {}
+
     def on_render_vars(self, vars : dict):
         '''
             call when render html page by jinja2
@@ -267,10 +281,17 @@ class Plugin_Base:
             with open(path, encoding='utf-8') as f:
                 content = f.read()
                 for k, v in vars.items():
-                    content = content.replace("${}{}{}".format("{", k.strip(), "}"), v)
+                    if v is None:
+                        v = "null"
+                    content = content.replace("${}{}{}".format("{", k.strip(), "}"), str(v))
                 temp_path = os.path.join(temp_dir, os.path.basename(path))
                 with open(temp_path, "w", encoding='utf-8') as fw:
                     fw.write(content)
                 files[url] = temp_path
         return files
 
+    def get_temp_dir(self):
+        self.temp_dir = os.path.join(tempfile.gettempdir(), self.name)
+        if not os.path.exists(self.temp_dir):
+            os.makedirs(self.temp_dir)
+        return self.temp_dir
